#########################################################################
###EXAMPLE - HOW TO USE SET OF BUILT FUNCTIONS TO KERNEL ESTIMATIONS#####
#########################################################################
######################JUL-2019###########################################
################################ESTIMATION AND VISUALIZATION#############
#########################################################################

#REQUIRED PACKAGES
library(adehabitatHR)
library(rgdal)
library(maptools)
library(RgoogleMaps)
library(animation)
library(animation)
library(rgeos)
library(png)
library(geosphere)
library(maps)  
library(ks)
source("LinearRange_for_paper.R") #OUR SET OF FUNCTIONS TO DEAL WITH 1D-KERNEL

##########################
##LINEAR RANGE ESTIMATES##
##########################

#LOADING DATA
loc=read.table("example_data.txt",h=T)
coords=SpatialPointsDataFrame(loc[,c("long","lat")],proj4string=CRS("+datum=WGS84 +proj=longlat"),data=loc)
coords.utm=spTransform(coords,CRS=CRS("+proj=utm +zone=21 +south"))

#LOAD RIVER
riverline=readOGR("rioline.kml",layer="rioline.kml")
riverline=as(spTransform(riverline,CRS=CRS("+proj=utm +zone=21 +south")),"SpatialLines")

#PLOT LOCATION AND RIVER
plot(riverline,lwd=4,col=4,axes=T)
plot(coords.utm,add=T,col=2,pch=16)

##DISTANCE POINT-LINE
river=gInterpolate(riverline,seq(0,gLength(riverline),5))
river=SpatialLines(list(Lines(list(Line(coordinates(river))),ID=1)),proj4string=CRS(proj4string(river)))
riverOne=rioOne(river) #CONVERTING BIDIMENSIONAL RIVER IN ONE-DIMENSIONAL
new=newloc1D(coords.utm,river,coords.utm$id) #PUT LOCATION ON RIVER
sort=sort_loc(new,river,new$id) #SORT LOCATION IN ORDER ALONG THE RIVER
one=oneD(sort,river,sort$id) #COVERTING BIDIMENSIONAL RELOCATION TO ONE-DIMENSIONAL

###HOME RANGE ESTIMATION
#RIVER RANGE
lext=line_extreme(one,one$id)
lext

#KERNEL LINEAR RANGE (UTILIZATION DISTRIBUTION PROBABILITIES)
list=split(one,one$id)
kernel=kd1(list,h=20)
iso95=kiso(kernel,95)
iso50=kiso(kernel,50)

#ONE DIMENSIONAL KERNEL ESTIMATION IN METERS
lr95=linerange(iso95,river,riverOne)
lr95$lrange
lr50=linerange(iso50,river,riverOne)
lr50$lrange

#SPATIAL RANGES
kline95=kd2(coords.utm,riverline,h="href",iso=95)
kline95$lrange
kline50=kd2(coords.utm,riverline,h="href",iso=50)
kline50$lrange

#PLOTING RANGES
plot(riverline,lwd=4,col=4,axes=T)
plot(coords.utm,add=T,col=2,pch=16)
plot.lrange(kline95,riverline,coo=coords.utm,earth=F)
legend("topright",legend=c("River","K1D-95%","K1D-50%"),lwd=2,col=c(4,1,2))

